@@ -376,10 +376,18 @@ def _serialize_range(value):
     return value or None
 
 def _parse_int(value):
-    if value is None:
+    if value is None or value == '':
         return None
     return int(value)
 
+def _parse_int_safe(value):
+    if value is None or value == '':
+        return None
+    try:
+        return int(value)
+    except ValueError:
+        return None
+
 def _serialize_int(value):
     if value is None:
         return None
@@ -542,10 +550,14 @@ class Request(object):
     content_type = environ_getter('CONTENT_TYPE', rfc_section='14.17')
     content_length = converter(
         environ_getter('CONTENT_LENGTH', rfc_section='14.13'),
-        _parse_int, _serialize_int, 'int')
+        _parse_int_safe, _serialize_int, 'int')
     remote_user = environ_getter('REMOTE_USER', default=None)
     remote_addr = environ_getter('REMOTE_ADDR', default=None)
     query_string = environ_getter('QUERY_STRING')
+    server_name = environ_getter('SERVER_NAME')
+    server_port = converter(
+        environ_getter('SERVER_PORT'),
+        _parse_int, _serialize_int, 'int')
 
     _headers = None
 
@@ -685,7 +697,7 @@ class Request(object):
         path = path.lstrip('/')
         return path.split('/', 1)[0]
 
-    def urlvars__get(self):
+    def _urlvars__get(self):
         """
         Return any variables matched in the URL (e.g.,
         ``wsgiorg.routing_args``).
@@ -699,17 +711,17 @@ class Request(object):
             self.environ['wsgiorg.routing_args'] = ((), result)
             return result
 
-    def urlvars__set(self, value):
+    def _urlvars__set(self, value):
         del self.urlvars
         self.environ['wsgiorg.routing_args'] = ((), value)
 
-    def urlvars__del(self):
+    def _urlvars__del(self):
         if 'paste.urlvars' in self.environ:
             del self.environ['paste.urlvars']
         if 'wsgiorg.routing_args' in self.environ:
             del self.environ['wsgiorg.routing_args']
             
-    urlvars = property(urlvars__get, urlvars__set, urlvars__del, doc=urlvars__get.__doc__)
+    urlvars = property(_urlvars__get, _urlvars__set, _urlvars__del, doc=_urlvars__get.__doc__)
 
     def is_xhr(self):
         """Returns a boolean if X-Requested-With is present and ``XMLHttpRequest``"""
@@ -786,7 +798,7 @@ class Request(object):
             vars, body_file = env['paste.parsed_formvars']
             if body_file is self.body_file:
                 # FIXME: is it okay that this isn't *our* MultiDict?
-                return parsed
+                return vars
         content_type = self.content_type
         if ';' in content_type:
             content_type = content_type.split(';', 1)[0]
@@ -1675,7 +1687,7 @@ class Response(object):
 
     age = converter(
         header_getter('Age', rfc_section='14.6'),
-        _parse_int, _serialize_int, 'int')
+        _parse_int_safe, _serialize_int, 'int')
 
     allow = converter(
         header_getter('Allow', rfc_section='14.7'),
